@@ -53,17 +53,18 @@ class BaseSession(abc.ABC):
     @staticmethod
     def wrap_multirequest(
         method: Union[AvtocodMethod[AvtocodType], List[AvtocodMethod[AvtocodType]]],
-        data: Dict[str, Any],
-    ) -> List[Dict[str, Any]]:
+        data: Any,
+    ) -> Any:
         if isinstance(method, MultiRequest):
-            return cast(List[Dict[str, Any]], data)
+            return data
         return [data]
 
     @staticmethod
     def unwrap_multirequest(method: AvtocodMethod[AvtocodType], data: List[Any]) -> Any:
         if isinstance(method, MultiRequest):
             return data
-        return data[0]
+        if data:
+            return data[0]
 
     def check_response(
         self, method: AvtocodMethod[AvtocodType], content_type: str, content: str
@@ -79,17 +80,13 @@ class BaseSession(abc.ABC):
         parsed_responses: List[Optional[AvtocodType]] = []
         errors: List[Tuple[int, AvtocodException]] = []
 
-        for index, data in enumerate(self.wrap_multirequest(method, json_data)):
-            try:
-                parsed_responses.append(method.build_response(data))
-            except AvtocodException as e:
-                parsed_responses.append(None)
-                errors.append(
-                    (
-                        index,
-                        e,
-                    )
-                )
+        for index, data in enumerate(
+            method.build_responses_from_generator(self.wrap_multirequest(method, json_data))
+        ):
+            if isinstance(data, AvtocodException):
+                errors.append((index, data))
+                continue
+            parsed_responses.append(data)
 
         return (
             self.unwrap_multirequest(method, parsed_responses),
